@@ -19,6 +19,12 @@ TEST_KWARGS = {
     'logResult' : False
 }
 
+def getRaisedException(callableThing, *args, **kwargs):
+    try:
+        callableThing(*args, **kwargs)
+    except Exception as exception:
+        return exception
+
 def getUnitTest(inspectGlobals, globalsInstance) :
     @Test(**getGlobalsTestKwargs(inspectGlobals, globalsInstance))
     def unitTest(testModule, testName, data, testReturns, logResult) :
@@ -62,6 +68,7 @@ def getModuleTest(inspectGlobals, logResult, globalsInstance) :
             , wrapperStatus = globalsInstance.wrapperStatus
             , testStatus = globalsInstance.testStatus
             , logStatus = globalsInstance.logStatus
+            , infoStatus = globalsInstance.infoStatus,
         )
         LogHelper.test(tddModule, f'{testName} started')
         testReturns = {}
@@ -96,6 +103,11 @@ def getModuleTest(inspectGlobals, logResult, globalsInstance) :
 def runModuleTests(testName, runnableTddModule, times, runSpecificTests, testsToRun, logResult, globalsInstance) :
     import globals
     testModule = globals.importModule(testName)
+    if ObjectHelper.isNone(testModule):
+        errorMessage = f'Not possible to import {testName}'
+        exception = Exception(f'Not possible to import {testName}')
+        LogHelper.error(runModuleTests, f'{errorMessage}. Please check warnings for more details', exception)
+        raise exception
     dataList = ReflectionHelper.getAttributeDataList(testModule)
     LogHelper.prettyPython(runnableTddModule, f'{ReflectionHelper.getName(testModule)} tests loaded', dataList, logLevel=LogHelper.TEST)
     allShouldRun, someShouldRun, allDidRun, someDidRun = getRunStatus(testModule, dataList, runSpecificTests, testsToRun)
@@ -167,6 +179,7 @@ def run(
     wrapperStatus = False,
     testStatus = False,
     logStatus = False,
+    infoStatus = True,
     inspectGlobals = False,
     logResult = True
 ) :
@@ -181,6 +194,7 @@ def run(
         , wrapperStatus = wrapperStatus
         , testStatus = testStatus
         , logStatus = logStatus
+        , infoStatus = infoStatus
     )
     testModuleNames, testsToRun, runSpecificTests = getTestModuleNames(runOnly, ignore, globalsInstance)
     returns = {}
@@ -255,6 +269,7 @@ def getTestRuntimeInfo(times, testTime, totalTestTime) :
 def getTestEnvironmentVariables(globalsInstance) :
     return {
         LogHelper.LOG : globalsInstance.logStatus,
+        LogHelper.INFO : globalsInstance.infoStatus,
         LogHelper.SUCCESS : globalsInstance.successStatus,
         LogHelper.SETTING : globalsInstance.settingStatus,
         LogHelper.DEBUG : globalsInstance.debugStatus,
